@@ -6,9 +6,9 @@
 :created: 7/6/2019
 """
 
-from docx2python.main import docx2python
+from docx2python.main import get_docx_content
 
-INST = docx2python("resources/example.docx")
+INST = get_docx_content("resources/example.docx")
 
 
 class TestDocument:
